@@ -65,8 +65,7 @@ __all__ = [
 
 
 import itertools as it
-from collections.abc import Iterable, Sequence
-from typing import Callable
+from collections.abc import Callable, Iterable, Sequence
 
 from manim.mobject.geometry.line import Line
 from manim.mobject.geometry.polygram import Polygon
@@ -254,7 +253,7 @@ class Table(VGroup):
         self,
         table: Iterable[Iterable[float | str | VMobject]],
     ) -> list:
-        """Initilaizes the entries of ``table`` as :class:`~.VMobject`.
+        """Initializes the entries of ``table`` as :class:`~.VMobject`.
 
         Parameters
         ----------
