@@ -20,9 +20,9 @@
 
 from __future__ import annotations
 
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from os import PathLike
-from typing import Callable, Union
+from typing import Union
 
 import numpy as np
 import numpy.typing as npt
@@ -32,20 +32,24 @@ __all__ = [
     "ManimFloat",
     "ManimInt",
     "ManimColorDType",
-    "RGB_Array_Float",
-    "RGB_Tuple_Float",
-    "RGB_Array_Int",
-    "RGB_Tuple_Int",
-    "RGBA_Array_Float",
-    "RGBA_Tuple_Float",
-    "RGBA_Array_Int",
-    "RGBA_Tuple_Int",
-    "HSV_Array_Float",
-    "HSV_Tuple_Float",
-    "HSL_Array_Float",
-    "HSL_Tuple_Float",
-    "HSVA_Array_Float",
-    "HSVA_Tuple_Float",
+    "FloatRGB",
+    "FloatRGBLike",
+    "FloatRGB_Array",
+    "FloatRGBLike_Array",
+    "IntRGB",
+    "IntRGBLike",
+    "FloatRGBA",
+    "FloatRGBALike",
+    "FloatRGBA_Array",
+    "FloatRGBALike_Array",
+    "IntRGBA",
+    "IntRGBALike",
+    "FloatHSV",
+    "FloatHSVLike",
+    "FloatHSL",
+    "FloatHSLLike",
+    "FloatHSVA",
+    "FloatHSVALike",
     "ManimColorInternal",
     "PointDType",
     "Point2D",
@@ -61,11 +65,17 @@ __all__ = [
     "PointND_Array",
     "PointNDLike_Array",
     "Vector2D",
+    "Vector2DLike",
     "Vector2D_Array",
+    "Vector2DLike_Array",
     "Vector3D",
+    "Vector3DLike",
     "Vector3D_Array",
+    "Vector3DLike_Array",
     "VectorND",
+    "VectorNDLike",
     "VectorND_Array",
+    "VectorNDLike_Array",
     "RowVector",
     "ColVector",
     "MatrixMN",
@@ -137,7 +147,7 @@ ManimColorDType: TypeAlias = ManimFloat
 double-precision float between 0 and 1.
 """
 
-RGB_Array_Float: TypeAlias = npt.NDArray[ManimColorDType]
+FloatRGB: TypeAlias = npt.NDArray[ManimColorDType]
 """``shape: (3,)``
 
 A :class:`numpy.ndarray` of 3 floats between 0 and 1, representing a
@@ -147,17 +157,32 @@ Its components describe, in order, the intensity of Red, Green, and
 Blue in the represented color.
 """
 
-RGB_Tuple_Float: TypeAlias = tuple[float, float, float]
+FloatRGBLike: TypeAlias = Union[FloatRGB, tuple[float, float, float]]
 """``shape: (3,)``
 
-A tuple of 3 floats between 0 and 1, representing a color in RGB
+An array of 3 floats between 0 and 1, representing a color in RGB
 format.
 
-Its components describe, in order, the intensity of Red, Green, and
-Blue in the represented color.
+This represents anything which can be converted to a :class:`.FloatRGB` NumPy
+array.
 """
 
-RGB_Array_Int: TypeAlias = npt.NDArray[ManimInt]
+FloatRGB_Array: TypeAlias = npt.NDArray[ManimColorDType]
+"""``shape: (M, 3)``
+
+A :class:`numpy.ndarray` of many rows of 3 floats representing RGB colors.
+"""
+
+FloatRGBLike_Array: TypeAlias = Union[FloatRGB_Array, Sequence[FloatRGBLike]]
+"""``shape: (M, 3)``
+
+An array of many rows of 3 floats representing RGB colors.
+
+This represents anything which can be converted to a :class:`.FloatRGB_Array` NumPy
+array.
+"""
+
+IntRGB: TypeAlias = npt.NDArray[ManimInt]
 """``shape: (3,)``
 
 A :class:`numpy.ndarray` of 3 integers between 0 and 255,
@@ -167,17 +192,17 @@ Its components describe, in order, the intensity of Red, Green, and
 Blue in the represented color.
 """
 
-RGB_Tuple_Int: TypeAlias = tuple[int, int, int]
+IntRGBLike: TypeAlias = Union[IntRGB, tuple[int, int, int]]
 """``shape: (3,)``
 
-A tuple of 3 integers between 0 and 255, representing a color in RGB
+An array of 3 integers between 0 and 255, representing a color in RGB
 format.
 
-Its components describe, in order, the intensity of Red, Green, and
-Blue in the represented color.
+This represents anything which can be converted to an :class:`.IntRGB` NumPy
+array.
 """
 
-RGBA_Array_Float: TypeAlias = npt.NDArray[ManimColorDType]
+FloatRGBA: TypeAlias = npt.NDArray[ManimColorDType]
 """``shape: (4,)``
 
 A :class:`numpy.ndarray` of 4 floats between 0 and 1, representing a
@@ -187,17 +212,32 @@ Its components describe, in order, the intensity of Red, Green, Blue
 and Alpha (opacity) in the represented color.
 """
 
-RGBA_Tuple_Float: TypeAlias = tuple[float, float, float, float]
+FloatRGBALike: TypeAlias = Union[FloatRGBA, tuple[float, float, float, float]]
 """``shape: (4,)``
 
-A tuple of 4 floats between 0 and 1, representing a color in RGBA
+An array of 4 floats between 0 and 1, representing a color in RGBA
 format.
 
-Its components describe, in order, the intensity of Red, Green, Blue
-and Alpha (opacity) in the represented color.
+This represents anything which can be converted to a :class:`.FloatRGBA` NumPy
+array.
 """
 
-RGBA_Array_Int: TypeAlias = npt.NDArray[ManimInt]
+FloatRGBA_Array: TypeAlias = npt.NDArray[ManimColorDType]
+"""``shape: (M, 4)``
+
+A :class:`numpy.ndarray` of many rows of 4 floats representing RGBA colors.
+"""
+
+FloatRGBALike_Array: TypeAlias = Union[FloatRGBA_Array, Sequence[FloatRGBALike]]
+"""``shape: (M, 4)``
+
+An array of many rows of 4 floats representing RGBA colors.
+
+This represents anything which can be converted to a :class:`.FloatRGBA_Array` NumPy
+array.
+"""
+
+IntRGBA: TypeAlias = npt.NDArray[ManimInt]
 """``shape: (4,)``
 
 A :class:`numpy.ndarray` of 4 integers between 0 and 255,
@@ -207,17 +247,17 @@ Its components describe, in order, the intensity of Red, Green, Blue
 and Alpha (opacity) in the represented color.
 """
 
-RGBA_Tuple_Int: TypeAlias = tuple[int, int, int, int]
+IntRGBALike: TypeAlias = Union[IntRGBA, tuple[int, int, int, int]]
 """``shape: (4,)``
 
-A tuple of 4 integers between 0 and 255, representing a color in RGBA
+An array of 4 integers between 0 and 255, representing a color in RGBA
 format.
 
-Its components describe, in order, the intensity of Red, Green, Blue
-and Alpha (opacity) in the represented color.
+This represents anything which can be converted to an :class:`.IntRGBA` NumPy
+array.
 """
 
-HSV_Array_Float: TypeAlias = RGB_Array_Float
+FloatHSV: TypeAlias = FloatRGB
 """``shape: (3,)``
 
 A :class:`numpy.ndarray` of 3 floats between 0 and 1, representing a
@@ -227,17 +267,17 @@ Its components describe, in order, the Hue, Saturation and Value (or
 Brightness) in the represented color.
 """
 
-HSV_Tuple_Float: TypeAlias = RGB_Tuple_Float
+FloatHSVLike: TypeAlias = FloatRGBLike
 """``shape: (3,)``
 
-A tuple of 3 floats between 0 and 1, representing a color in HSV (or
+An array of 3 floats between 0 and 1, representing a color in HSV (or
 HSB) format.
 
-Its components describe, in order, the Hue, Saturation and Value (or
-Brightness) in the represented color.
+This represents anything which can be converted to a :class:`.FloatHSV` NumPy
+array.
 """
 
-HSVA_Array_Float: TypeAlias = RGBA_Array_Float
+FloatHSVA: TypeAlias = FloatRGBA
 """``shape: (4,)``
 
 A :class:`numpy.ndarray` of 4 floats between 0 and 1, representing a
@@ -247,17 +287,17 @@ Its components describe, in order, the Hue, Saturation and Value (or
 Brightness) in the represented color.
 """
 
-HSVA_Tuple_Float: TypeAlias = RGBA_Tuple_Float
+FloatHSVALike: TypeAlias = FloatRGBALike
 """``shape: (4,)``
 
-A tuple of 4 floats between 0 and 1, representing a color in HSVA (or
+An array of 4 floats between 0 and 1, representing a color in HSVA (or
 HSBA) format.
 
-Its components describe, in order, the Hue, Saturation and Value (or
-Brightness) in the represented color.
+This represents anything which can be converted to a :class:`.FloatHSVA` NumPy
+array.
 """
 
-HSL_Array_Float: TypeAlias = RGB_Array_Float
+FloatHSL: TypeAlias = FloatRGB
 """``shape: (3,)``
 
 A :class:`numpy.ndarray` of 3 floats between 0 and 1, representing a
@@ -267,17 +307,16 @@ Its components describe, in order, the Hue, Saturation and Lightness
 in the represented color.
 """
 
-HSL_Tuple_Float: TypeAlias = RGB_Tuple_Float
+FloatHSLLike: TypeAlias = FloatRGBLike
 """``shape: (3,)``
 
-A :class:`numpy.ndarray` of 3 floats between 0 and 1, representing a
-color in HSL format.
+An array of 3 floats between 0 and 1, representing a color in HSL format.
 
-Its components describe, in order, the Hue, Saturation and Lightness
-in the represented color.
+This represents anything which can be converted to a :class:`.FloatHSL` NumPy
+array.
 """
 
-ManimColorInternal: TypeAlias = RGBA_Array_Float
+ManimColorInternal: TypeAlias = FloatRGBA
 """``shape: (4,)``
 
 Internal color representation used by :class:`~.ManimColor`,
@@ -310,31 +349,25 @@ Point2DLike: TypeAlias = Union[Point2D, tuple[float, float]]
 
 A 2-dimensional point: ``[float, float]``.
 
-This represents anything which can be converted to a :class:`Point2D` NumPy
+This represents anything which can be converted to a :class:`.Point2D` NumPy
 array.
-
-Normally, a function or method which expects a `Point2D` as a
-parameter can handle being passed a `Point3D` instead.
 """
 
 Point2D_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape: (M, 2)``
 
-A NumPy array representing a sequence of `Point2D` objects:
+A NumPy array representing a sequence of :class:`.Point2D` objects:
 ``[[float, float], ...]``.
 """
 
 Point2DLike_Array: TypeAlias = Union[Point2D_Array, Sequence[Point2DLike]]
 """``shape: (M, 2)``
 
-An array of `Point2DLike` objects: ``[[float, float], ...]``.
+An array of :class:`.Point2DLike` objects: ``[[float, float], ...]``.
 
-This represents anything which can be converted to a :class:`Point2D_Array`
+This represents anything which can be converted to a :class:`.Point2D_Array`
 NumPy array.
 
-Normally, a function or method which expects a `Point2D_Array` as a
-parameter can handle being passed a `Point3D_Array` instead.
-
 Please refer to the documentation of the function you are using for
 further type information.
 """
@@ -350,23 +383,23 @@ Point3DLike: TypeAlias = Union[Point3D, tuple[float, float, float]]
 
 A 3-dimensional point: ``[float, float, float]``.
 
-This represents anything which can be converted to a :class:`Point3D` NumPy
+This represents anything which can be converted to a :class:`.Point3D` NumPy
 array.
 """
 
 Point3D_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape: (M, 3)``
 
-A NumPy array representing a sequence of `Point3D` objects:
+A NumPy array representing a sequence of :class:`.Point3D` objects:
 ``[[float, float, float], ...]``.
 """
 
 Point3DLike_Array: TypeAlias = Union[Point3D_Array, Sequence[Point3DLike]]
 """``shape: (M, 3)``
 
-An array of `Point3D` objects: ``[[float, float, float], ...]``.
+An array of :class:`.Point3DLike` objects: ``[[float, float, float], ...]``.
 
-This represents anything which can be converted to a :class:`Point3D_Array`
+This represents anything which can be converted to a :class:`.Point3D_Array`
 NumPy array.
 
 Please refer to the documentation of the function you are using for
@@ -384,23 +417,23 @@ PointNDLike: TypeAlias = Union[PointND, Sequence[float]]
 
 An N-dimensional point: ``[float, ...]``.
 
-This represents anything which can be converted to a :class:`PointND` NumPy
+This represents anything which can be converted to a :class:`.PointND` NumPy
 array.
 """
 
 PointND_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape: (M, N)``
 
-A NumPy array representing a sequence of `PointND` objects:
+A NumPy array representing a sequence of :class:`.PointND` objects:
 ``[[float, ...], ...]``.
 """
 
 PointNDLike_Array: TypeAlias = Union[PointND_Array, Sequence[PointNDLike]]
 """``shape: (M, N)``
 
-An array of `PointND` objects: ``[[float, ...], ...]``.
+An array of :class:`.PointNDLike` objects: ``[[float, ...], ...]``.
 
-This represents anything which can be converted to a :class:`PointND_Array`
+This represents anything which can be converted to a :class:`.PointND_Array`
 NumPy array.
 
 Please refer to the documentation of the function you are using for
@@ -416,10 +449,20 @@ Vector types
 Vector2D: TypeAlias = npt.NDArray[PointDType]
 """``shape: (2,)``
 
+A NumPy array representing a 2-dimensional vector: ``[float, float]``.
+
+.. caution::
+    Do not confuse with the :class:`~.Vector` or :class:`~.Arrow`
+    VMobjects!
+"""
+
+Vector2DLike: TypeAlias = Union[npt.NDArray[PointDType], tuple[float, float]]
+"""``shape: (2,)``
+
 A 2-dimensional vector: ``[float, float]``.
 
-Normally, a function or method which expects a `Vector2D` as a
-parameter can handle being passed a `Vector3D` instead.
+This represents anything which can be converted to a :class:`.Vector2D` NumPy
+array.
 
 .. caution::
     Do not confuse with the :class:`~.Vector` or :class:`~.Arrow`
@@ -429,17 +472,37 @@ parameter can handle being passed a `Vector3D` instead.
 Vector2D_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape: (M, 2)``
 
-An array of `Vector2D` objects: ``[[float, float], ...]``.
+A NumPy array representing a sequence of :class:`.Vector2D` objects:
+``[[float, float], ...]``.
+"""
 
-Normally, a function or method which expects a `Vector2D_Array` as a
-parameter can handle being passed a `Vector3D_Array` instead.
+Vector2DLike_Array: TypeAlias = Union[Vector2D_Array, Sequence[Vector2DLike]]
+"""``shape: (M, 2)``
+
+An array of :class:`.Vector2DLike` objects: ``[[float, float], ...]``.
+
+This represents anything which can be converted to a :class:`.Vector2D_Array`
+NumPy array.
 """
 
 Vector3D: TypeAlias = npt.NDArray[PointDType]
 """``shape: (3,)``
 
+A NumPy array representing a 3-dimensional vector: ``[float, float, float]``.
+
+.. caution::
+    Do not confuse with the :class:`~.Vector` or :class:`~.Arrow3D`
+    VMobjects!
+"""
+
+Vector3DLike: TypeAlias = Union[npt.NDArray[PointDType], tuple[float, float, float]]
+"""``shape: (3,)``
+
 A 3-dimensional vector: ``[float, float, float]``.
 
+This represents anything which can be converted to a :class:`.Vector3D` NumPy
+array.
+
 .. caution::
     Do not confuse with the :class:`~.Vector` or :class:`~.Arrow3D`
     VMobjects!
@@ -448,14 +511,38 @@ A 3-dimensional vector: ``[float, float, float]``.
 Vector3D_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape: (M, 3)``
 
-An array of `Vector3D` objects: ``[[float, float, float], ...]``.
+An NumPy array representing a sequence of :class:`.Vector3D` objects:
+``[[float, float, float], ...]``.
+"""
+
+Vector3DLike_Array: TypeAlias = Union[npt.NDArray[PointDType], Sequence[Vector3DLike]]
+"""``shape: (M, 3)``
+
+An array of :class:`.Vector3DLike` objects: ``[[float, float, float], ...]``.
+
+This represents anything which can be converted to a :class:`.Vector3D_Array`
+NumPy array.
 """
 
 VectorND: TypeAlias = npt.NDArray[PointDType]
 """``shape (N,)``
 
+A NumPy array representing an :math:`N`-dimensional vector: ``[float, ...]``.
+
+.. caution::
+    Do not confuse with the :class:`~.Vector` VMobject! This type alias
+    is named "VectorND" instead of "Vector" to avoid potential name
+    collisions.
+"""
+
+VectorNDLike: TypeAlias = Union[npt.NDArray[PointDType], Sequence[float]]
+"""``shape (N,)``
+
 An :math:`N`-dimensional vector: ``[float, ...]``.
 
+This represents anything which can be converted to a :class:`.VectorND` NumPy
+array.
+
 .. caution::
     Do not confuse with the :class:`~.Vector` VMobject! This type alias
     is named "VectorND" instead of "Vector" to avoid potential name
@@ -465,7 +552,17 @@ An :math:`N`-dimensional vector: ``[float, ...]``.
 VectorND_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape (M, N)``
 
-An array of `VectorND` objects: ``[[float, ...], ...]``.
+A NumPy array representing a sequence of :class:`.VectorND` objects:
+``[[float, ...], ...]``.
+"""
+
+VectorNDLike_Array: TypeAlias = Union[npt.NDArray[PointDType], Sequence[VectorNDLike]]
+"""``shape (M, N)``
+
+An array of :class:`.VectorNDLike` objects: ``[[float, ...], ...]``.
+
+This represents anything which can be converted to a :class:`.VectorND_Array`
+NumPy array.
 """
 
 RowVector: TypeAlias = npt.NDArray[PointDType]
@@ -495,7 +592,7 @@ A matrix: ``[[float, ...], [float, ...], ...]``.
 Zeros: TypeAlias = MatrixMN
 """``shape: (M, N)``
 
-A `MatrixMN` filled with zeros, typically created with
+A :class:`.MatrixMN` filled with zeros, typically created with
 ``numpy.zeros((M, N))``.
 """
 
@@ -508,7 +605,7 @@ Bézier types
 QuadraticBezierPoints: TypeAlias = Point3D_Array
 """``shape: (3, 3)``
 
-A `Point3D_Array` of three 3D control points for a single quadratic Bézier
+A :class:`.Point3D_Array` of three 3D control points for a single quadratic Bézier
 curve:
 ``[[float, float, float], [float, float, float], [float, float, float]]``.
 """
@@ -518,18 +615,18 @@ QuadraticBezierPointsLike: TypeAlias = Union[
 ]
 """``shape: (3, 3)``
 
-A `Point3DLike_Array` of three 3D control points for a single quadratic Bézier
+A :class:`.Point3DLike_Array` of three 3D control points for a single quadratic Bézier
 curve:
 ``[[float, float, float], [float, float, float], [float, float, float]]``.
 
 This represents anything which can be converted to a
-:class:`QuadraticBezierPoints` NumPy array.
+:class:`.QuadraticBezierPoints` NumPy array.
 """
 
 QuadraticBezierPoints_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape: (N, 3, 3)``
 
-A NumPy array containing :math:`N` `QuadraticBezierPoints` objects:
+A NumPy array containing :math:`N` :class:`.QuadraticBezierPoints` objects:
 ``[[[float, float, float], [float, float, float], [float, float, float]], ...]``.
 """
 
@@ -538,17 +635,17 @@ QuadraticBezierPointsLike_Array: TypeAlias = Union[
 ]
 """``shape: (N, 3, 3)``
 
-A sequence of :math:`N` `QuadraticBezierPointsLike` objects:
+A sequence of :math:`N` :class:`.QuadraticBezierPointsLike` objects:
 ``[[[float, float, float], [float, float, float], [float, float, float]], ...]``.
 
 This represents anything which can be converted to a
-:class:`QuadraticBezierPoints_Array` NumPy array.
+:class:`.QuadraticBezierPoints_Array` NumPy array.
 """
 
 QuadraticBezierPath: TypeAlias = Point3D_Array
 """``shape: (3*N, 3)``
 
-A `Point3D_Array` of :math:`3N` points, where each one of the
+A :class:`.Point3D_Array` of :math:`3N` points, where each one of the
 :math:`N` consecutive blocks of 3 points represents a quadratic
 Bézier curve:
 ``[[float, float, float], ...], ...]``.
@@ -560,13 +657,13 @@ further type information.
 QuadraticBezierPathLike: TypeAlias = Point3DLike_Array
 """``shape: (3*N, 3)``
 
-A `Point3DLike_Array` of :math:`3N` points, where each one of the
+A :class:`.Point3DLike_Array` of :math:`3N` points, where each one of the
 :math:`N` consecutive blocks of 3 points represents a quadratic
 Bézier curve:
 ``[[float, float, float], ...], ...]``.
 
 This represents anything which can be converted to a
-:class:`QuadraticBezierPath` NumPy array.
+:class:`.QuadraticBezierPath` NumPy array.
 
 Please refer to the documentation of the function you are using for
 further type information.
@@ -575,7 +672,7 @@ further type information.
 QuadraticSpline: TypeAlias = QuadraticBezierPath
 """``shape: (3*N, 3)``
 
-A special case of `QuadraticBezierPath` where all the :math:`N`
+A special case of :class:`.QuadraticBezierPath` where all the :math:`N`
 quadratic Bézier curves are connected, forming a quadratic spline:
 ``[[float, float, float], ...], ...]``.
 
@@ -586,11 +683,11 @@ further type information.
 QuadraticSplineLike: TypeAlias = QuadraticBezierPathLike
 """``shape: (3*N, 3)``
 
-A special case of `QuadraticBezierPathLike` where all the :math:`N`
+A special case of :class:`.QuadraticBezierPathLike` where all the :math:`N`
 quadratic Bézier curves are connected, forming a quadratic spline:
 ``[[float, float, float], ...], ...]``.
 
-This represents anything which can be converted to a :class:`QuadraticSpline`
+This represents anything which can be converted to a :class:`.QuadraticSpline`
 NumPy array.
 
 Please refer to the documentation of the function you are using for
@@ -600,7 +697,7 @@ further type information.
 CubicBezierPoints: TypeAlias = Point3D_Array
 """``shape: (4, 3)``
 
-A `Point3D_Array` of four 3D control points for a single cubic Bézier curve:
+A :class:`.Point3D_Array` of four 3D control points for a single cubic Bézier curve:
 ``[[float, float, float], [float, float, float], [float, float, float], [float, float, float]]``.
 """
 
@@ -609,17 +706,17 @@ CubicBezierPointsLike: TypeAlias = Union[
 ]
 """``shape: (4, 3)``
 
-A `Point3DLike_Array` of 4 control points for a single cubic Bézier curve:
+A :class:`.Point3DLike_Array` of 4 control points for a single cubic Bézier curve:
 ``[[float, float, float], [float, float, float], [float, float, float], [float, float, float]]``.
 
-This represents anything which can be converted to a :class:`CubicBezierPoints`
+This represents anything which can be converted to a :class:`.CubicBezierPoints`
 NumPy array.
 """
 
 CubicBezierPoints_Array: TypeAlias = npt.NDArray[PointDType]
 """``shape: (N, 4, 3)``
 
-A NumPy array containing :math:`N` `CubicBezierPoints` objects:
+A NumPy array containing :math:`N` :class:`.CubicBezierPoints` objects:
 ``[[[float, float, float], [float, float, float], [float, float, float], [float, float, float]], ...]``.
 """
 
@@ -628,17 +725,17 @@ CubicBezierPointsLike_Array: TypeAlias = Union[
 ]
 """``shape: (N, 4, 3)``
 
-A sequence of :math:`N` `CubicBezierPointsLike` objects:
+A sequence of :math:`N` :class:`.CubicBezierPointsLike` objects:
 ``[[[float, float, float], [float, float, float], [float, float, float], [float, float, float]], ...]``.
 
 This represents anything which can be converted to a
-:class:`CubicBezierPoints_Array` NumPy array.
+:class:`.CubicBezierPoints_Array` NumPy array.
 """
 
 CubicBezierPath: TypeAlias = Point3D_Array
 """``shape: (4*N, 3)``
 
-A `Point3D_Array` of :math:`4N` points, where each one of the
+A :class:`.Point3D_Array` of :math:`4N` points, where each one of the
 :math:`N` consecutive blocks of 4 points represents a cubic Bézier
 curve:
 ``[[float, float, float], ...], ...]``.
@@ -650,13 +747,13 @@ further type information.
 CubicBezierPathLike: TypeAlias = Point3DLike_Array
 """``shape: (4*N, 3)``
 
-A `Point3DLike_Array` of :math:`4N` points, where each one of the
+A :class:`.Point3DLike_Array` of :math:`4N` points, where each one of the
 :math:`N` consecutive blocks of 4 points represents a cubic Bézier
 curve:
 ``[[float, float, float], ...], ...]``.
 
 This represents anything which can be converted to a
-:class:`CubicBezierPath` NumPy array.
+:class:`.CubicBezierPath` NumPy array.
 
 Please refer to the documentation of the function you are using for
 further type information.
@@ -665,7 +762,7 @@ further type information.
 CubicSpline: TypeAlias = CubicBezierPath
 """``shape: (4*N, 3)``
 
-A special case of `CubicBezierPath` where all the :math:`N` cubic
+A special case of :class:`.CubicBezierPath` where all the :math:`N` cubic
 Bézier curves are connected, forming a quadratic spline:
 ``[[float, float, float], ...], ...]``.
 
@@ -676,12 +773,12 @@ further type information.
 CubicSplineLike: TypeAlias = CubicBezierPathLike
 """``shape: (4*N, 3)``
 
-A special case of `CubicBezierPath` where all the :math:`N` cubic
+A special case of :class:`.CubicBezierPath` where all the :math:`N` cubic
 Bézier curves are connected, forming a quadratic spline:
 ``[[float, float, float], ...], ...]``.
 
 This represents anything which can be converted to a
-:class:`CubicSpline` NumPy array.
+:class:`.CubicSpline` NumPy array.
 
 Please refer to the documentation of the function you are using for
 further type information.
@@ -690,7 +787,7 @@ further type information.
 BezierPoints: TypeAlias = Point3D_Array
 r"""``shape: (PPC, 3)``
 
-A `Point3D_Array` of :math:`\text{PPC}` control points
+A :class:`.Point3D_Array` of :math:`\text{PPC}` control points
 (:math:`\text{PPC: Points Per Curve} = n + 1`) for a single
 :math:`n`-th degree Bézier curve:
 ``[[float, float, float], ...]``.
@@ -702,13 +799,13 @@ further type information.
 BezierPointsLike: TypeAlias = Point3DLike_Array
 r"""``shape: (PPC, 3)``
 
-A `Point3DLike_Array` of :math:`\text{PPC}` control points
+A :class:`.Point3DLike_Array` of :math:`\text{PPC}` control points
 (:math:`\text{PPC: Points Per Curve} = n + 1`) for a single
 :math:`n`-th degree Bézier curve:
 ``[[float, float, float], ...]``.
 
 This represents anything which can be converted to a
-:class:`BezierPoints` NumPy array.
+:class:`.BezierPoints` NumPy array.
 
 Please refer to the documentation of the function you are using for
 further type information.
@@ -717,8 +814,8 @@ further type information.
 BezierPoints_Array: TypeAlias = npt.NDArray[PointDType]
 r"""``shape: (N, PPC, 3)``
 
-A NumPy array of :math:`N` `BezierPoints` objects containing
-:math:`\text{PPC}` `Point3D` objects each
+A NumPy array of :math:`N` :class:`.BezierPoints` objects containing
+:math:`\text{PPC}` :class:`.Point3D` objects each
 (:math:`\text{PPC: Points Per Curve} = n + 1`):
 ``[[[float, float, float], ...], ...]``.
 
@@ -731,13 +828,13 @@ BezierPointsLike_Array: TypeAlias = Union[
 ]
 r"""``shape: (N, PPC, 3)``
 
-A sequence of :math:`N` `BezierPointsLike` objects containing
-:math:`\text{PPC}` `Point3DLike` objects each
+A sequence of :math:`N` :class:`.BezierPointsLike` objects containing
+:math:`\text{PPC}` :class:`.Point3DLike` objects each
 (:math:`\text{PPC: Points Per Curve} = n + 1`):
 ``[[[float, float, float], ...], ...]``.
 
 This represents anything which can be converted to a
-:class:`BezierPoints_Array` NumPy array.
+:class:`.BezierPoints_Array` NumPy array.
 
 Please refer to the documentation of the function you are using for
 further type information.
@@ -746,7 +843,7 @@ further type information.
 BezierPath: TypeAlias = Point3D_Array
 r"""``shape: (PPC*N, 3)``
 
-A `Point3D_Array` of :math:`\text{PPC} \cdot N` points, where each
+A :class:`.Point3D_Array` of :math:`\text{PPC} \cdot N` points, where each
 one of the :math:`N` consecutive blocks of :math:`\text{PPC}` control
 points (:math:`\text{PPC: Points Per Curve} = n + 1`) represents a
 Bézier curve of :math:`n`-th degree:
@@ -759,14 +856,14 @@ further type information.
 BezierPathLike: TypeAlias = Point3DLike_Array
 r"""``shape: (PPC*N, 3)``
 
-A `Point3DLike_Array` of :math:`\text{PPC} \cdot N` points, where each
+A :class:`.Point3DLike_Array` of :math:`\text{PPC} \cdot N` points, where each
 one of the :math:`N` consecutive blocks of :math:`\text{PPC}` control
 points (:math:`\text{PPC: Points Per Curve} = n + 1`) represents a
 Bézier curve of :math:`n`-th degree:
 ``[[float, float, float], ...], ...]``.
 
 This represents anything which can be converted to a
-:class:`BezierPath` NumPy array.
+:class:`.BezierPath` NumPy array.
 
 Please refer to the documentation of the function you are using for
 further type information.
@@ -775,8 +872,8 @@ further type information.
 Spline: TypeAlias = BezierPath
 r"""``shape: (PPC*N, 3)``
 
-A special case of `BezierPath` where all the :math:`N` Bézier curves
-consisting of :math:`\text{PPC}` `Point3D` objects
+A special case of :class:`.BezierPath` where all the :math:`N` Bézier curves
+consisting of :math:`\text{PPC}` :class:`.Point3D` objects
 (:math:`\text{PPC: Points Per Curve} = n + 1`) are connected, forming
 an :math:`n`-th degree spline:
 ``[[float, float, float], ...], ...]``.
@@ -788,14 +885,14 @@ further type information.
 SplineLike: TypeAlias = BezierPathLike
 r"""``shape: (PPC*N, 3)``
 
-A special case of `BezierPathLike` where all the :math:`N` Bézier curves
-consisting of :math:`\text{PPC}` `Point3D` objects
+A special case of :class:`.BezierPathLike` where all the :math:`N` Bézier curves
+consisting of :math:`\text{PPC}` :class:`.Point3D` objects
 (:math:`\text{PPC: Points Per Curve} = n + 1`) are connected, forming
 an :math:`n`-th degree spline:
 ``[[float, float, float], ...], ...]``.
 
 This represents anything which can be converted to a
-:class:`Spline` NumPy array.
+:class:`.Spline` NumPy array.
 
 Please refer to the documentation of the function you are using for
 further type information.
@@ -825,16 +922,16 @@ FunctionOverride: TypeAlias = Callable
 """
 
 PathFuncType: TypeAlias = Callable[[Point3DLike, Point3DLike, float], Point3DLike]
-"""Function mapping two :class:`Point3D` objects and an alpha value to a new
-:class:`Point3D`.
+"""Function mapping two :class:`.Point3D` objects and an alpha value to a new
+:class:`.Point3D`.
 """
 
 MappingFunction: TypeAlias = Callable[[Point3D], Point3D]
-"""A function mapping a :class:`Point3D` to another :class:`Point3D`."""
+"""A function mapping a :class:`.Point3D` to another :class:`.Point3D`."""
 
 MultiMappingFunction: TypeAlias = Callable[[Point3D_Array], Point3D_Array]
-"""A function mapping a :class:`Point3D_Array` to another
-:class:`Point3D_Array`.
+"""A function mapping a :class:`.Point3D_Array` to another
+:class:`.Point3D_Array`.
 """
 
 """
@@ -851,29 +948,29 @@ A rasterized image with a height of ``height`` pixels and a width of
 Every value in the array is an integer from 0 to 255.
 
 Every pixel is represented either by a single integer indicating its
-lightness (for greyscale images), an `RGB_Array_Int` or an
+lightness (for greyscale images), an :class:`.RGB_Array_Int` or an
 `RGBA_Array_Int`.
 """
 
 GrayscalePixelArray: TypeAlias = PixelArray
 """``shape: (height, width)``
 
-A 100% opaque grayscale `PixelArray`, where every pixel value is a
+A 100% opaque grayscale :class:`.PixelArray`, where every pixel value is a
 `ManimInt` indicating its lightness (black -> gray -> white).
 """
 
 RGBPixelArray: TypeAlias = PixelArray
 """``shape: (height, width, 3)``
 
-A 100% opaque `PixelArray` in color, where every pixel value is an
+A 100% opaque :class:`.PixelArray` in color, where every pixel value is an
 `RGB_Array_Int` object.
 """
 
 RGBAPixelArray: TypeAlias = PixelArray
 """``shape: (height, width, 4)``
 
-A `PixelArray` in color where pixels can be transparent. Every pixel
-value is an `RGBA_Array_Int` object.
+A :class:`.PixelArray` in color where pixels can be transparent. Every pixel
+value is an :class:`.RGBA_Array_Int` object.
 """
 
 
@@ -883,11 +980,11 @@ Path types
 """
 
 StrPath: TypeAlias = Union[str, PathLike[str]]
-"""A string or :class:`os.PathLike` representing a path to a
+"""A string or :class:`.os.PathLike` representing a path to a
 directory or file.
 """
 
 StrOrBytesPath: TypeAlias = Union[str, bytes, PathLike[str], PathLike[bytes]]
-"""A string, bytes or :class:`os.PathLike` object representing a path
+"""A string, bytes or :class:`.os.PathLike` object representing a path
 to a directory or file.
 """
